ChatBubbleThemePatterns extension

Adds pattern-matching-related methods to ChatBubbleTheme.

on

Methods

map<TResult extends Object?>(TResult $default(_ChatBubbleTheme value)) → TResult

Available on ChatBubbleTheme, provided by the ChatBubbleThemePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ChatBubbleTheme value)?) → TResult?

Available on ChatBubbleTheme, provided by the ChatBubbleThemePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ChatBubbleTheme value)?, {required TResult orElse()}) → TResult

Available on ChatBubbleTheme, provided by the ChatBubbleThemePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(Color? outgoingColor, Color? incomingColor, TextStyle? outgoingTextStyle, TextStyle? incomingTextStyle, BorderRadius? borderRadius, TextStyle? timestampStyle, TextStyle? outgoingTimestampStyle, TextStyle? incomingTimestampStyle, Color? statusColor, Color? statusReadColor, Color? mentionColor, TextStyle? editedLabelStyle, Color? forwardedLabelColor, TextStyle? forwardedLabelStyle, TextStyle? senderNameStyle, Color? failedIconColor)?, {required TResult orElse()}) → TResult

Available on ChatBubbleTheme, provided by the ChatBubbleThemePatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(Color? outgoingColor, Color? incomingColor, TextStyle? outgoingTextStyle, TextStyle? incomingTextStyle, BorderRadius? borderRadius, TextStyle? timestampStyle, TextStyle? outgoingTimestampStyle, TextStyle? incomingTimestampStyle, Color? statusColor, Color? statusReadColor, Color? mentionColor, TextStyle? editedLabelStyle, Color? forwardedLabelColor, TextStyle? forwardedLabelStyle, TextStyle? senderNameStyle, Color? failedIconColor)) → TResult

Available on ChatBubbleTheme, provided by the ChatBubbleThemePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(Color? outgoingColor, Color? incomingColor, TextStyle? outgoingTextStyle, TextStyle? incomingTextStyle, BorderRadius? borderRadius, TextStyle? timestampStyle, TextStyle? outgoingTimestampStyle, TextStyle? incomingTimestampStyle, Color? statusColor, Color? statusReadColor, Color? mentionColor, TextStyle? editedLabelStyle, Color? forwardedLabelColor, TextStyle? forwardedLabelStyle, TextStyle? senderNameStyle, Color? failedIconColor)?) → TResult?

Available on ChatBubbleTheme, provided by the ChatBubbleThemePatterns extension

A variant of when that fallback to returning null