PendingChatMessage class abstract

A locally-persisted outgoing message that has not been confirmed by the server. isFailed is true when the last send attempt returned an error; when false, the message is still pending (in flight or queued).

Available extensions
Annotations
  • @freezed

Constructors

PendingChatMessage(ChatMessage message, {@Default.new(false) bool isFailed})
const
factory

Properties

copyWith → $PendingChatMessageCopyWith<PendingChatMessage>
Create a copy of PendingChatMessage with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isFailed bool
no setterinherited
message ChatMessage
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_PendingChatMessage value)) → TResult

Available on PendingChatMessage, provided by the PendingChatMessagePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PendingChatMessage value)?) → TResult?

Available on PendingChatMessage, provided by the PendingChatMessagePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PendingChatMessage value)?, {required TResult orElse()}) → TResult

Available on PendingChatMessage, provided by the PendingChatMessagePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(ChatMessage message, bool isFailed)?, {required TResult orElse()}) → TResult

Available on PendingChatMessage, provided by the PendingChatMessagePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(ChatMessage message, bool isFailed)) → TResult

Available on PendingChatMessage, provided by the PendingChatMessagePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(ChatMessage message, bool isFailed)?) → TResult?

Available on PendingChatMessage, provided by the PendingChatMessagePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited