ReceiptUpdatedEvent class final

Inheritance

Constructors

ReceiptUpdatedEvent({required String roomId, required String messageId, required ReceiptStatus status, String? fromUserId})
const

Properties

fromUserId String?
final
hashCode int
The hash code for this object.
no setteroverride
messageId String
final
roomId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status ReceiptStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override