ThreadView class
Displays a message thread: the parent message, its replies, and an input for new replies.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- ThreadView
Constructors
-
ThreadView({Key? key, required ChatMessage parentMessage, required ChatController controller, List<
ChatMessage> replies = const [], ValueChanged<String> ? onSendReply, VoidCallback? onLoadMore, VoidCallback? onClose, ChatTheme theme = ChatTheme.defaults, String? currentUserId, Widget messageBubbleBuilder(BuildContext, ChatMessage, bool)?}) -
const
Properties
- controller → ChatController
-
final
- currentUserId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- messageBubbleBuilder → Widget Function(BuildContext, ChatMessage, bool)?
-
final
- onClose → VoidCallback?
-
final
- onLoadMore → VoidCallback?
-
final
-
onSendReply
→ ValueChanged<
String> ? -
final
- parentMessage → ChatMessage
-
final
-
replies
→ List<
ChatMessage> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → ChatTheme
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited