uploadCount property

int uploadCount
getter/setter pair

How many times upload has been called, failures included. Lets a test assert that a path which re-posts an already-uploaded blob — a retrySend on an attachment whose send failed — does not upload the bytes a second time.

Implementation

int uploadCount = 0;