ChatRoomOptionConfirmation class
Confirmation dialog config attached to a ChatRoomOption. When present, ChatRoomOptionsMenu shows the dialog after the user taps the option; the action only fires if the user confirms.
- Annotations
Constructors
- ChatRoomOptionConfirmation({required String title, required String body, required String acceptLabel, required String cancelLabel})
-
const
Properties
- acceptLabel → String
-
final
- body → String
-
final
- cancelLabel → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited