DeliveryStatusLegendEntry class
One row of DeliveryStatusLegendSheet: the glyph the timeline paints for state, its short name and the sentence that explains it.
- Annotations
Constructors
- DeliveryStatusLegendEntry({required MessageDeliveryState state, required String title, required String description})
-
const
Properties
- description → String
-
The explaining sentence (
ChatUiLocalizations.statusReadDescription, …).final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → MessageDeliveryState
-
final
- title → String
-
Short name of the state (
ChatUiLocalizations.statusRead, …).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited