RoomDetail class abstract
Detailed room information including the current user's role and room configuration.
- Available extensions
- Annotations
-
- @freezed
Constructors
-
RoomDetail({required String id, String? name, String? subject, required RoomType type, required int memberCount, required RoomRole userRole, required RoomConfig config, @Default.new(false) bool muted, DateTime? muteUntil, @Default.new(false) bool pinned, @Default.new(false) bool selfMuted, DateTime? createdAt, String? avatarUrl, Map<
String, dynamic> ? custom}) -
constfactory
Properties
- avatarUrl → String?
-
no setterinherited
- config → RoomConfig
-
no setterinherited
-
copyWith
→ $RoomDetailCopyWith<
RoomDetail> -
Create a copy of RoomDetail
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → DateTime?
-
no setterinherited
-
custom
→ Map<
String, dynamic> ? -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
no setterinherited
- id → String
-
no setterinherited
- isReadOnly → bool
-
True when the composer must be read-only: an announcement channel the
user doesn't own, OR the user has been moderation-muted in this room
(an admin/owner silenced them).
selfMutedis distinct frommuted(the user's own notification preference).no setter - memberCount → int
-
no setterinherited
- muted → bool
-
no setterinherited
- muteUntil → DateTime?
-
When the notification mute expires (UTC).
nullmeans a permanent mute (or not muted — checkmuted).no setterinherited - name → String?
-
no setterinherited
- pinned → bool
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfMuted → bool
-
no setterinherited
- subject → String?
-
no setterinherited
- type → RoomType
-
no setterinherited
- userRole → RoomRole
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_RoomDetail value)) → TResult -
Available on RoomDetail, provided by the RoomDetailPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_RoomDetail value)?) → TResult? -
Available on RoomDetail, provided by the RoomDetailPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_RoomDetail value)?, {required TResult orElse()}) → TResult -
Available on RoomDetail, provided by the RoomDetailPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String id, String? name, String? subject, RoomType type, int memberCount, RoomRole userRole, RoomConfig config, bool muted, DateTime? muteUntil, bool pinned, bool selfMuted, DateTime? createdAt, String? avatarUrl, Map< String, dynamic> ? custom)?, {required TResult orElse()}) → TResult -
Available on RoomDetail, provided by the RoomDetailPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String id, String? name, String? subject, RoomType type, int memberCount, RoomRole userRole, RoomConfig config, bool muted, DateTime? muteUntil, bool pinned, bool selfMuted, DateTime? createdAt, String? avatarUrl, Map< String, dynamic> ? custom)) → TResult -
Available on RoomDetail, provided by the RoomDetailPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String id, String? name, String? subject, RoomType type, int memberCount, RoomRole userRole, RoomConfig config, bool muted, DateTime? muteUntil, bool pinned, bool selfMuted, DateTime? createdAt, String? avatarUrl, Map< String, dynamic> ? custom)?) → TResult? -
Available on RoomDetail, provided by the RoomDetailPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited